==> testsuite-1.0.0-beta1.tar.gz: testsuite/src/LoadResourceService.php <==
<?php

namespace Drupal\testsuite;

use Drupal\Core\Database\Connection;
use Drupal\Core\Session\AccountInterface;

/**
 * Test Suite Services.
 */
class LoadResourceService {

    protected $_menuArray = array(
        'custom' => array(),
        'contrib' => array(),
        'core' => array()
    );

    protected $_formReportArray = array();

    protected $_listFilesArray = array();
    /**
     * @var \Drupal\Core\Database\Connection
     */
    protected $_connection;

    /**
     * @var \Drupal\Core\Session\AccountInterface
     */
    protected $_account;

    protected $_path;

    protected $_version;

    /**
     * @param \Drupal\Core\Database\Connection $connection
     * @param \Drupal\Core\Session\AccountInterface $account
     */
    public function __construct(Connection $connection, AccountInterface $account) {
        $this->_connection = $connection;
        $this->_account = $account;
        $this->_path = dirname(dirname(dirname(dirname(__DIR__))));
        $this->_version = \Drupal::VERSION;
        // dd((float)$this->_version < (float)'9.0');
    }

    private function hasWebFolder() {
        $path = dirname(dirname(dirname(__DIR__)));
        if (preg_match('/\bweb\b/', $path)) return true;
        else return false;
    }
    
    /**
     * Gets the array of files to create classes with.
     *
     * @return array
     *   The array of files to create classes with.
     */
    public function getResource($caller, $testType, $area, $module, $directory) {
        switch($testType) {
            case 'custom': return glob($this->_path . '/modules/custom/testsuite/src/Tests/*.php');
            case 'phpunit':
                if($caller == 'menu') {
                    $this->_getDirectories('core', $this->_path . '/core/modules');
                    $this->_getDirectories('contrib', $this->_path . '/modules/contrib');
                    $this->_getDirectories('custom', $this->_path . '/modules/custom');
                    return $this->_menuArray;
                } else {
                    switch($area) {
                        case 'core'; $this->_getFormReportArray('core', $module, $directory, $this->_path . '/core/modules'); break;
                        case 'contrib'; $this->_getFormReportArray('contrib', $module, $directory, $this->_path . '/modules/contrib'); break;
                        case 'custom'; $this->_getFormReportArray('custom', $module, $directory, $this->_path . '/modules/custom'); break;
                    }
                    return $this->_formReportArray;
                }
            case 'selenium': break;
        }
    }

    public function getFileStatement($area, $module, $directory, $filePath) {
        $parts = explode("/", $filePath);
        $file = end($parts);
        // dd($file);
        if($this->hasWebFolder()) {
            if(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
                switch($area) {
                    case 'core': return 'vendor\bin\phpunit --debug -c web\core web\\'.$area.'\modules\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                    case 'contrib': return 'vendor\bin\phpunit --debug -c web\core web\modules\contrib\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                    case 'custom': return 'vendor\bin\phpunit --debug -c web\core web\modules\custom\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                }
            } else {
                switch($area) {
                    case 'core': return 'vendor/bin/phpunit --debug -c web/core web/'.$area.'/modules/'.$module.'/tests/src/'.$directory.'/'.$file;
                    case 'contrib': return 'vendor/bin/phpunit --debug -c web/core web/modules/contrib/'.$module.'/tests/src/'.$directory.'/'.$file;
                    case 'custom': return 'vendor/bin/phpunit --debug -c web/core web/modules/custom/'.$module.'/tests/src/'.$directory.'/'.$file;
                }
            }
        } else {
            if(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
                switch($area) {
                    case 'core': return 'vendor\bin\phpunit --debug -c core '.$area.'\modules\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                    case 'contrib': return 'vendor\bin\phpunit --debug -c core modules\contrib\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                    case 'custom': return 'vendor\bin\phpunit --debug -c core modules\custom\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                }
            } else {
                switch($area) {
                    case 'core': return 'vendor/bin/phpunit --debug -c core '.$area.'/modules/'.$module.'/tests/src/'.$directory.'/'.$file;
                    case 'contrib': return 'vendor/bin/phpunit --debug -c core modules/contrib/'.$module.'/tests/src/'.$directory.'/'.$file;
                    case 'custom': return 'vendor/bin/phpunit --debug -c core modules/custom/'.$module.'/tests/src/'.$directory.'/'.$file;
                }
            }
        }
    }

    private function getUrls($area, $module, $directory, $statement = null) {
        if($statement) {
            $parts = explode("/", $statement);
            $link = \Drupal::request()->getSchemeAndHttpHost() ."/admin/testsuite/phpunit/file/report/". $area ."/". $module ."/". $directory ."/". end($parts);
        } else {
            $link = \Drupal::request()->getSchemeAndHttpHost() ."/admin/testsuite/phpunit/file/report/". $area ."/". $module ."/". $directory;
        }
        
        return $link;
    }

    public function getFiles($area, $module, $directory) {
        $path = "";
        switch($area) {
            case 'core'; $path = $this->_path . '/core/modules'; break;
            case 'contrib'; $path = $this->_path . '/modules/contrib'; break;
            case 'custom'; $path = $this->_path . '/modules/custom'; break;
        }
        $this->_getFilesInDirectories($area, $module, $directory, $path);
        return $this->_listFilesArray;
    }

    public function getStatement($area, $module, $directory) {
        if($this->hasWebFolder()) {
            if(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
                switch($area) {
                    case 'core': return 'vendor\bin\phpunit --debug -c web\core web\\'.$area.'\modules\\'.$module.'\tests\src\\'.$directory;
                    case 'contrib': return 'vendor\bin\phpunit --debug -c web\core web\modules\contrib\\'.$module.'\tests\src\\'.$directory;
                    case 'custom': return 'vendor\bin\phpunit --debug -c web\core web\modules\custom\\'.$module.'\tests\src\\'.$directory;
                }
            } else {
                switch($area) {
                    case 'core': return 'vendor/bin/phpunit --debug -c web/core web/'.$area.'/modules/'.$module.'/tests/src/'.$directory;
                    case 'contrib': return 'vendor/bin/phpunit --debug -c web/core web/modules/contrib/'.$module.'/tests/src/'.$directory;
                    case 'custom': return 'vendor/bin/phpunit --debug -c web/core web/modules/custom/'.$module.'/tests/src/'.$directory;
                }
            }
        } else {
            if(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
                switch($area) {
                    case 'core': return 'vendor\bin\phpunit --debug -c core '.$area.'\modules\\'.$module.'\tests\src\\'.$directory;
                    case 'contrib': return 'vendor\bin\phpunit --debug -c core modules\contrib\\'.$module.'\tests\src\\'.$directory;
                    case 'custom': return 'vendor\bin\phpunit --debug -c core modules\custom\\'.$module.'\tests\src\\'.$directory;
                }
            } else {
                switch($area) {
                    case 'core': return 'vendor/bin/phpunit --debug -c core '.$area.'/modules/'.$module.'/tests/src/'.$directory;
                    case 'contrib': return 'vendor/bin/phpunit --debug -c core modules/contrib/'.$module.'/tests/src/'.$directory;
                    case 'custom': return 'vendor/bin/phpunit --debug -c core modules/custom/'.$module.'/tests/src/'.$directory;
                }
            }
        }
    }

    private function _getDirectories($area, $path) {
        $scan = scandir($path);
        unset($scan[array_search('.', $scan, true)]);
        unset($scan[array_search('..', $scan, true)]);
        foreach($scan as $module) {
            if (is_dir("$path/$module")) {
                $testsPath = "$path/$module/tests/src/";
                if(is_dir($testsPath)) {
                    $testsScan = scandir($testsPath);
                    unset($testsScan[array_search('.', $testsScan, true)]);
                    unset($testsScan[array_search('..', $testsScan, true)]);
                    foreach($testsScan as $directory) {
                        if (is_dir("$testsPath/$directory")) {
                            $this->_menuArray[$area][$module][] = $directory;
                        }
                    }
                }
            }
        }
    }

    private function _getFilesInDirectories($area, $moduleModules, $moduleDirectory, $path) {
        $scan = scandir($path);
        unset($scan[array_search('.', $scan, true)]);
        unset($scan[array_search('..', $scan, true)]);
        foreach($scan as $module) {
            if($moduleModules == $module) {
                if (is_dir("$path/$module")) {
                    $testsPath = "$path/$module/tests/src";
                    if(is_dir($testsPath)) {
                        $testsScan = scandir($testsPath);
                        unset($testsScan[array_search('.', $testsScan, true)]);
                        unset($testsScan[array_search('..', $testsScan, true)]);
                        foreach($testsScan as $directory) {
                            // var_dump("$testsPath/$directory");
                            if($moduleDirectory == $directory) {
                                if (is_dir("$testsPath/$directory")) {
                                    // if($moduleModules == 'testsuite') {
                                        $globPath = "$path/$module/tests/src/$directory";
                                        $globedFiles = glob($globPath.'/*.php');
                                        foreach($globedFiles as $file) {
                                            $this->_listFilesArray[] = $this->getUrls($area, $moduleModules, $moduleDirectory, $file);
                                        }
                                    /* } else {
                                        $this->_listFilesArray[] = $this->getUrls($area, $moduleModules, $moduleDirectory);
                                    } */
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    private function _getFormReportArray($area, $moduleModules, $moduleDirectory, $path) {
        $scan = scandir($path);
        unset($scan[array_search('.', $scan, true)]);
        unset($scan[array_search('..', $scan, true)]);
        foreach($scan as $module) {
            if (is_dir("$path/$module")) {
                $testsPath = "$path/$module/tests/src/";
                if(is_dir($testsPath)) {
                    $testsScan = scandir($testsPath);
                    unset($testsScan[array_search('.', $testsScan, true)]);
                    unset($testsScan[array_search('..', $testsScan, true)]);
                    foreach($testsScan as $directory) {
                        if($moduleDirectory == $directory) {
                            if (is_dir("$testsPath/$directory") && !isset($this->_formReportArray[$module])) {
                                if($moduleModules == 'all') {
                                    $this->_formReportArray[$module] = $this->getStatement($area, $module, $directory);
                                } else {
                                    if($moduleModules == $module) $this->_formReportArray[$module] = $this->getStatement($area, $module, $directory);
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}

==> testsuite-1.0.8-beta1.tar.gz: testsuite/src/LoadResourceService.php <==
<?php

namespace Drupal\testsuite;

use Drupal\Core\Database\Connection;
use Drupal\Core\Session\AccountInterface;

/**
 * Test Suite Services.
 */
class LoadResourceService {

    protected $_menuArray = array(
        'custom' => array(),
        'contrib' => array(),
        'core' => array()
    );

    protected $_formReportArray = array();

    protected $_listFilesArray = array();
    /**
     * @var \Drupal\Core\Database\Connection
     */
    protected $_connection;

    /**
     * @var \Drupal\Core\Session\AccountInterface
     */
    protected $_account;

    protected $_path;

    protected $_version;

    /**
     * @param \Drupal\Core\Database\Connection $connection
     * @param \Drupal\Core\Session\AccountInterface $account
     */
    public function __construct(Connection $connection, AccountInterface $account) {
        $this->_connection = $connection;
        $this->_account = $account;
        $this->_path = dirname(dirname(dirname(dirname(__DIR__))));
        $this->_version = \Drupal::VERSION;
        // dd((float)$this->_version < (float)'9.0');
    }

    private function hasWebFolder() {
        $path = dirname(dirname(dirname(__DIR__)));
        if (preg_match('/\bweb\b/', $path)) return true;
        else return false;
    }

    /**
     * Gets the array of files to create classes with.
     *
     * @return array
     *   The array of files to create classes with.
     */
    public function getResource($caller, $testType, $area, $module, $directory) {
        switch($testType) {
            case 'custom': return glob($this->_path . '/modules/contrib/testsuite/src/Tests/*.php');
            case 'phpunit':
                if($caller == 'menu') {
                    $this->_getDirectories('core', $this->_path . '/core/modules');
                    $this->_getDirectories('contrib', $this->_path . '/modules/contrib');
                    $this->_getDirectories('custom', $this->_path . '/modules/custom');
                    return $this->_menuArray;
                } else {
                    switch($area) {
                        case 'core'; $this->_getFormReportArray('core', $module, $directory, $this->_path . '/core/modules'); break;
                        case 'contrib'; $this->_getFormReportArray('contrib', $module, $directory, $this->_path . '/modules/contrib'); break;
                        case 'custom'; $this->_getFormReportArray('custom', $module, $directory, $this->_path . '/modules/custom'); break;
                    }
                    return $this->_formReportArray;
                }
            case 'selenium': break;
        }
    }

    public function getFileStatement($area, $module, $directory, $filePath) {
        $parts = explode("/", $filePath);
        $file = end($parts);
        // dd($file);
        if($this->hasWebFolder()) {
            if(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
                switch($area) {
                    case 'core': return 'vendor\bin\phpunit --debug -c web\core web\\'.$area.'\modules\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                    case 'contrib': return 'vendor\bin\phpunit --debug -c web\core web\modules\contrib\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                    case 'custom': return 'vendor\bin\phpunit --debug -c web\core web\modules\custom\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                }
            } else {
                switch($area) {
                    case 'core': return 'vendor/bin/phpunit --debug -c web/core web/'.$area.'/modules/'.$module.'/tests/src/'.$directory.'/'.$file;
                    case 'contrib': return 'vendor/bin/phpunit --debug -c web/core web/modules/contrib/'.$module.'/tests/src/'.$directory.'/'.$file;
                    case 'custom': return 'vendor/bin/phpunit --debug -c web/core web/modules/custom/'.$module.'/tests/src/'.$directory.'/'.$file;
                }
            }
        } else {
            if(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
                switch($area) {
                    case 'core': return 'vendor\bin\phpunit --debug -c core '.$area.'\modules\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                    case 'contrib': return 'vendor\bin\phpunit --debug -c core modules\contrib\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                    case 'custom': return 'vendor\bin\phpunit --debug -c core modules\custom\\'.$module.'\tests\src\\'.$directory.'\\'.$file;
                }
            } else {
                switch($area) {
                    case 'core': return 'vendor/bin/phpunit --debug -c core '.$area.'/modules/'.$module.'/tests/src/'.$directory.'/'.$file;
                    case 'contrib': return 'vendor/bin/phpunit --debug -c core modules/contrib/'.$module.'/tests/src/'.$directory.'/'.$file;
                    case 'custom': return 'vendor/bin/phpunit --debug -c core modules/custom/'.$module.'/tests/src/'.$directory.'/'.$file;
                }
            }
        }
    }

    private function getUrls($area, $module, $directory, $statement = null) {
        if($statement) {
            $parts = explode("/", $statement);
            $link = \Drupal::request()->getSchemeAndHttpHost() ."/admin/testsuite/phpunit/file/report/". $area ."/". $module ."/". $directory ."/". end($parts);
        } else {
            $link = \Drupal::request()->getSchemeAndHttpHost() ."/admin/testsuite/phpunit/file/report/". $area ."/". $module ."/". $directory;
        }

        return $link;
    }

    public function getFiles($area, $module, $directory) {
        $path = "";
        switch($area) {
            case 'core'; $path = $this->_path . '/core/modules'; break;
            case 'contrib'; $path = $this->_path . '/modules/contrib'; break;
            case 'custom'; $path = $this->_path . '/modules/custom'; break;
        }
        $this->_getFilesInDirectories($area, $module, $directory, $path);
        return $this->_listFilesArray;
    }

    public function getStatement($area, $module, $directory) {
        if($this->hasWebFolder()) {
            if(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
                switch($area) {
                    case 'core': return 'vendor\bin\phpunit --debug -c web\core web\\'.$area.'\modules\\'.$module.'\tests\src\\'.$directory;
                    case 'contrib': return 'vendor\bin\phpunit --debug -c web\core web\modules\contrib\\'.$module.'\tests\src\\'.$directory;
                    case 'custom': return 'vendor\bin\phpunit --debug -c web\core web\modules\custom\\'.$module.'\tests\src\\'.$directory;
                }
            } else {
                switch($area) {
                    case 'core': return 'vendor/bin/phpunit --debug -c web/core web/'.$area.'/modules/'.$module.'/tests/src/'.$directory;
                    case 'contrib': return 'vendor/bin/phpunit --debug -c web/core web/modules/contrib/'.$module.'/tests/src/'.$directory;
                    case 'custom': return 'vendor/bin/phpunit --debug -c web/core web/modules/custom/'.$module.'/tests/src/'.$directory;
                }
            }
        } else {
            if(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
                switch($area) {
                    case 'core': return 'vendor\bin\phpunit --debug -c core '.$area.'\modules\\'.$module.'\tests\src\\'.$directory;
                    case 'contrib': return 'vendor\bin\phpunit --debug -c core modules\contrib\\'.$module.'\tests\src\\'.$directory;
                    case 'custom': return 'vendor\bin\phpunit --debug -c core modules\custom\\'.$module.'\tests\src\\'.$directory;
                }
            } else {
                switch($area) {
                    case 'core': return 'vendor/bin/phpunit --debug -c core '.$area.'/modules/'.$module.'/tests/src/'.$directory;
                    case 'contrib': return 'vendor/bin/phpunit --debug -c core modules/contrib/'.$module.'/tests/src/'.$directory;
                    case 'custom': return 'vendor/bin/phpunit --debug -c core modules/custom/'.$module.'/tests/src/'.$directory;
                }
            }
        }
    }

    private function _getDirectories($area, $path) {
        $scan = scandir($path);
        unset($scan[array_search('.', $scan, true)]);
        unset($scan[array_search('..', $scan, true)]);
        foreach($scan as $module) {
            if (is_dir("$path/$module")) {
                $testsPath = "$path/$module/tests/src/";
                if(is_dir($testsPath)) {
                    $testsScan = scandir($testsPath);
                    unset($testsScan[array_search('.', $testsScan, true)]);
                    unset($testsScan[array_search('..', $testsScan, true)]);
                    foreach($testsScan as $directory) {
                        if (is_dir("$testsPath/$directory")) {
                            $this->_menuArray[$area][$module][] = $directory;
                        }
                    }
                }
            }
        }
    }

    private function _getFilesInDirectories($area, $moduleModules, $moduleDirectory, $path) {
        $scan = scandir($path);
        unset($scan[array_search('.', $scan, true)]);
        unset($scan[array_search('..', $scan, true)]);
        foreach($scan as $module) {
            if($moduleModules == $module) {
                if (is_dir("$path/$module")) {
                    $testsPath = "$path/$module/tests/src";
                    if(is_dir($testsPath)) {
                        $testsScan = scandir($testsPath);
                        unset($testsScan[array_search('.', $testsScan, true)]);
                        unset($testsScan[array_search('..', $testsScan, true)]);
                        foreach($testsScan as $directory) {
                            // var_dump("$testsPath/$directory");
                            if($moduleDirectory == $directory) {
                                if (is_dir("$testsPath/$directory")) {
                                    // if($moduleModules == 'testsuite') {
                                        $globPath = "$path/$module/tests/src/$directory";
                                        $globedFiles = glob($globPath.'/*.php');
                                        foreach($globedFiles as $file) {
                                            $this->_listFilesArray[] = $this->getUrls($area, $moduleModules, $moduleDirectory, $file);
                                        }
                                    /* } else {
                                        $this->_listFilesArray[] = $this->getUrls($area, $moduleModules, $moduleDirectory);
                                    } */
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    private function _getFormReportArray($area, $moduleModules, $moduleDirectory, $path) {
        $scan = scandir($path);
        unset($scan[array_search('.', $scan, true)]);
        unset($scan[array_search('..', $scan, true)]);
        foreach($scan as $module) {
            if (is_dir("$path/$module")) {
                $testsPath = "$path/$module/tests/src/";
                if(is_dir($testsPath)) {
                    $testsScan = scandir($testsPath);
                    unset($testsScan[array_search('.', $testsScan, true)]);
                    unset($testsScan[array_search('..', $testsScan, true)]);
                    foreach($testsScan as $directory) {
                        if($moduleDirectory == $directory) {
                            if (is_dir("$testsPath/$directory") && !isset($this->_formReportArray[$module])) {
                                if($moduleModules == 'all') {
                                    $this->_formReportArray[$module] = $this->getStatement($area, $module, $directory);
                                } else {
                                    if($moduleModules == $module) $this->_formReportArray[$module] = $this->getStatement($area, $module, $directory);
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}
